DJANGO_APIS_FUNC_PARAMETERS_KEY = "_django_apis_func_parameters_key"
DJANGO_APIS_METHODS_KEY = "_django_apis_methods"
DJANGO_APIS_VIEW_FLAG_KEY = "_django_apis_view_flag"
DJANGO_APIS_APIVIEW_INSTANCE_KEY = "_django_apis_apiview_instance"

DJANGO_APIS_OPENAPI_SERVERS_KEY = "DJANGO_APIS_OPENAPI_SERVERS"
DJANGO_APIS_OPENAPI_SERVERS_DEFAULT = [
    {"url": "http://127.0.0.1:8000", "description": "本地开发环境"},
]

DJANGO_APIS_OPENAPI_TITLE_KEY = "DJANGO_APIS_OPENAPI_TITLE"

DJANGO_APIS_OPENAPI_VERSION_KEY = "DJANGO_APIS_OPENAPI_VERSION"
DJANGO_APIS_OPENAPI_VERSION_DEFAULT = "snapshot"

DJANGO_APIS_OPENAPI_DESCRIPTION_KEY = "DJANGO_APIS_OPENAPI_DESCRIPTION"
DJANGO_APIS_OPENAPI_DESCRIPTION_DEFAULT = "......"


DJANGO_APIS_OPENAPI_SECURITY_DEFINITIONS_KEY = (
    "DJANGO_APIS_OPENAPI_SECURITY_DEFINITIONS"
)

DJANGO_APIS_OPENAPI_SCHEMAS_KEY = "DJANGO_APIS_OPENAPI_SCHEMAS"
DJANGO_APIS_OPENAPI_LOGIN_URL_KEY = "DJANGO_APIS_OPENAPI_LOGIN_URL"
